@@ -1,7 +1,7 @@
 import argparse
 from argparse import Namespace
 
-from collection_framework.unique_collection import unique_symbol
+from .unique_collection import unique_symbol
 
 from .my_exceptions import NoArgumentsError
 
